@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import http
 import typing
 import warnings
@@ -9,8 +11,8 @@ class HTTPException(Exception):
     def __init__(
         self,
         status_code: int,
-        detail: typing.Optional[str] = None,
-        headers: typing.Optional[typing.Dict[str, str]] = None,
+        detail: str | None = None,
+        headers: dict[str, str] | None = None,
     ) -> None:
         if detail is None:
             detail = http.HTTPStatus(status_code).phrase
@@ -27,7 +29,7 @@ class HTTPException(Exception):
 
 
 class WebSocketException(Exception):
-    def __init__(self, code: int, reason: typing.Optional[str] = None) -> None:
+    def __init__(self, code: int, reason: str | None = None) -> None:
         self.code = code
         self.reason = reason or ""
 
@@ -56,5 +58,5 @@ def __getattr__(name: str) -> typing.Any:  # pragma: no cover
     raise AttributeError(f"module '{__name__}' has no attribute '{name}'")
 
 
-def __dir__() -> typing.List[str]:
+def __dir__() -> list[str]:
     return sorted(list(__all__) + [__deprecated__])  # pragma: no cover
